==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSummaryDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
        }
        static d(a) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ad("GridSummaryDescriptionsChangedEventArgs", () => new GridSummaryDescriptionsChangedEventArgsDescription());
            a.ac("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSummaryDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
        }
        static d(a) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ae("GridSummaryDescriptionsChangedEventArgs", () => new GridSummaryDescriptionsChangedEventArgsDescription());
            a.ad("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
})();
